@@ -6,6 +6,7 @@ from typing import Optional
 from zipfile import ZipFile, ZIP_DEFLATED
 
 from mcdreforged.plugin.meta.metadata import Metadata
+from mcdreforged.utils import file_util
 
 try:
 	from mcdreforged.constants import core_constant, plugin_constant
@@ -36,10 +37,10 @@ def entry_point():
 	subparsers = parser.add_subparsers(title='Command', help='Available commands', dest='subparser_name')
 
 	subparsers.add_parser('start', help='Start {}'.format(core_constant.NAME))
-	subparsers.add_parser('init', help='Prepare the working environment of {}. Create commonly used folders and generate default configure and permission files'.format(core_constant.NAME))
-	subparsers.add_parser('gendefault', help='Generate default configure and permission files at current working directory. Existed files will be overwritten')
+	subparsers.add_parser('init', help='Prepare the working environment of {}. Create commonly used folders and generate default configuration and permission files'.format(core_constant.NAME))
+	subparsers.add_parser('gendefault', help='Generate default configuration and permission files at current working directory. Existed files will be overwritten')
 
-	parser_pack = subparsers.add_parser('pack', help='Pack plugin files into a {} plugin'.format(plugin_constant.PACKED_PLUGIN_FILE_SUFFIX))
+	parser_pack = subparsers.add_parser('pack', help='Pack plugin files into a packed plugin')
 	parser_pack.add_argument('-i', '--input', help='The input directory which the plugin is in, default: current directory', default='.')
 	parser_pack.add_argument('-o', '--output', help='The output directory to store the zipped plugin, default: current directory', default='.')
 	parser_pack.add_argument('-n', '--name', help='A specific name to the output zipped plugin file. If not given the metadata specific name or a default one will be used', default=None)
@@ -83,7 +84,7 @@ def initialize_environment(*, quiet: bool = False):
 def generate_default_stuffs(*, quiet: bool = False):
 	MCDReforgedServer(generate_default_only=True)
 	if not quiet:
-		print('Generated default configure and permission files in {}'.format(os.getcwd()))
+		print('Generated default configuration and permission files in {}'.format(os.getcwd()))
 
 
 def make_packed_plugin(input_dir: str, output_dir: str, file_name: Optional[str], *, quiet: bool = False):
@@ -114,12 +115,18 @@ def make_packed_plugin(input_dir: str, output_dir: str, file_name: Optional[str]
 		file_name = meta.archive_name
 	if file_name is None:
 		file_name = '{}-v{}'.format(meta.name.replace(' ', '') or meta.id, meta.version)
-	file_name = file_name.format(id=meta.id, version=meta.version) + plugin_constant.PACKED_PLUGIN_FILE_SUFFIX
+
+	file_name = file_name.format(id=meta.id, version=meta.version)
+	if file_util.get_file_suffix(file_name) not in plugin_constant.PACKED_PLUGIN_FILE_SUFFIXES:
+		file_name += plugin_constant.PACKED_PLUGIN_FILE_SUFFIXES[0]
+	file_counter = 0
 
 	def write(base_path: str, *, directory_only: bool):
+		nonlocal file_counter
 		if os.path.isdir(base_path):
 			dir_arc = os.path.basename(base_path)
 			zip_file.write(base_path, arcname=dir_arc)
+			file_counter += 1
 			writeln('Creating directory: {} -> {}'.format(base_path, dir_arc))
 			for dir_path, dir_names, file_names in os.walk(base_path):
 				if os.path.basename(dir_path) == '__pycache__':
@@ -128,13 +135,17 @@ def make_packed_plugin(input_dir: str, output_dir: str, file_name: Optional[str]
 					full_path = os.path.join(dir_path, file_name_)
 					if os.path.isdir(full_path) and os.path.basename(full_path) == '__pycache__':
 						continue
-					arc_name = os.path.join(os.path.basename(base_path), full_path.replace(base_path, '', 1).lstrip(os.sep))
+					arc_name = os.path.join(dir_arc, full_path.replace(base_path, '', 1).lstrip(os.sep))
 					zip_file.write(full_path, arcname=arc_name)
+					file_counter += 1
 					writeln('  Writing: {} -> {}'.format(full_path, arc_name))
 		elif os.path.isfile(base_path) and not directory_only:
 			arc_name = os.path.basename(base_path)
 			zip_file.write(base_path, arcname=arc_name)
+			file_counter += 1
 			writeln('Writing single file: {} -> {}'.format(base_path, arc_name))
+		else:
+			writeln('[WARN] {} not found! ignored'.format(base_path))
 
 	writeln('Packing plugin "{}" into "{}" ...'.format(meta.id, file_name))
 	with ZipFile(os.path.join(output_dir, file_name), 'w', ZIP_DEFLATED) as zip_file:
@@ -144,4 +155,5 @@ def make_packed_plugin(input_dir: str, output_dir: str, file_name: Optional[str]
 		for resource_path in meta.resources:  # resources
 			write(os.path.join(input_dir, resource_path), directory_only=False)
 
+	writeln('Packed {} files/folders into "{}"'.format(file_counter, file_name))
 	writeln('Done')
