@@ -14,7 +14,7 @@ class Config(YamlDataStorage):
 	def __init__(self, logger: Logger):
 		super().__init__(logger, CONFIG_FILE, DEFAULT_CONFIG_RESOURCE_PATH)
 
-	def read_config(self, allowed_missing_file):
+	def read_config(self, allowed_missing_file: bool):
 		return self._load_data(allowed_missing_file)
 
 	def __getitem__(self, option: str):
