@@ -2,13 +2,13 @@
 Analyzing and reacting events related to player
 """
 from mcdreforged.info_reactor.abstract_info_reactor import AbstractInfoReactor
-from mcdreforged.info_reactor.info import InfoSource
+from mcdreforged.info_reactor.info import InfoSource, Info
 from mcdreforged.plugin.plugin_event import MCDRPluginEvents
 from mcdreforged.utils.logger import DebugOption
 
 
 class PlayerReactor(AbstractInfoReactor):
-	def react(self, info):
+	def react(self, info: Info):
 		if info.source == InfoSource.SERVER:
 			handler = self.mcdr_server.server_handler_manager.get_current_handler()
 
