@@ -2,26 +2,69 @@
 Plugin Version
 """
 import re
-from typing import List, Callable
+from typing import List, Callable, Tuple, Optional, Union
+
+
+# beta.3 -> (beta, 3), random -> (random, None)
+class ExtraElement:
+	DIVIDER = '.'
+	body: str
+	num: Optional[int]
+
+	def __init__(self, segment_str: str):
+		segments = segment_str.rsplit(self.DIVIDER, 1)
+		try:
+			self.body, self.num = segments[0], int(segments[1])
+		except (IndexError, ValueError):
+			self.body, self.num = segment_str, None
+
+	def __str__(self):
+		if self.num is None:
+			return self.body
+		return '{}{}{}'.format(self.body, self.DIVIDER, self.num)
+
+	def __lt__(self, other):
+		if not isinstance(other, type(self)):
+			raise TypeError()
+		if self.num is None or other.num is None:
+			return str(self) < str(other)
+		else:
+			return (self.body, self.num) < (other.body, other.num)
 
 
 class Version:
-	EXTRA_ID_PATTERN = re.compile(r'|[-0-9A-Za-z]+(\.[-0-9A-Za-z]+)*')
-	WILDCARDS = {'x', 'X', '*'}
+	"""
+	A version container that stores semver like version string
+
+	Example:
+
+	* ``"1.2.3"``
+	* ``"1.0.*"``
+	* ``"1.2.3-pre4+build.5"``
+	"""
+	EXTRA_ID_PATTERN = re.compile(r'|[-+0-9A-Za-z]+(\.[-+0-9A-Za-z]+)*')
+	WILDCARDS = ('*', 'x', 'X')
 	WILDCARD = -1
 
-	def __init__(self, version_str: str, allow_wildcard=True):
+	component: List[int]
+	has_wildcard: bool
+	pre: Optional[ExtraElement]
+	build: Optional[ExtraElement]
+
+	def __init__(self, version_str: str, *, allow_wildcard: bool = True):
 		"""
-		:param str version_str: the version str like '1.2.3-pre4+build.5'
+		:param version_str: The version string to be parsed
+		:keyword allow_wildcard: If wildcard (``"*"``, ``"x"``, ``"X"``) is allowed. Default: ``True``
 		"""
 		if not isinstance(version_str, str):
 			raise VersionParsingError('Invalid input version string')
 
-		def separate_extra(text, char):
+		def separate_extra(text, char) -> Tuple[str, Optional[ExtraElement]]:
 			if char in text:
-				text, extra = text.split(char, 1)
-				if not self.EXTRA_ID_PATTERN.fullmatch(extra):
-					raise VersionParsingError('Invalid build string: ' + extra)
+				text, extra_str = text.split(char, 1)
+				if not self.EXTRA_ID_PATTERN.fullmatch(extra_str):
+					raise VersionParsingError('Invalid build string: ' + extra_str)
+				extra = ExtraElement(extra_str)
 			else:
 				extra = None
 			return text, extra
@@ -52,14 +95,14 @@ class Version:
 			raise VersionParsingError('Empty version string')
 
 	def __str__(self):
-		version_str = '.'.join(map(str, self.component))
+		version_str = '.'.join(map(lambda c: str(c) if c != self.WILDCARD else self.WILDCARDS[0], self.component))
 		if self.pre is not None:
-			version_str += '-' + self.pre
+			version_str += '-' + str(self.pre)
 		if self.build is not None:
-			version_str += '+' + self.build
+			version_str += '+' + str(self.build)
 		return version_str
 
-	def __getitem__(self, index):
+	def __getitem__(self, index: int) -> int:
 		if index < len(self.component):
 			return self.component[index]
 		else:
@@ -97,20 +140,28 @@ class Version:
 			return 0
 
 
+DEFAULT_CRITERION_OPERATOR = '='
+
+
 class Criterion:
 	def __init__(self, opt: str, base_version: Version, criterion: Callable[[Version, Version], bool]):
 		self.opt = opt
 		self.base_version = base_version
 		self.criterion = criterion
 
-	def test(self, target: str or Version):
+	def test(self, target: Union[Version, str]):
 		return self.criterion(self.base_version, target)
 
 	def __str__(self):
-		return '{}{}'.format(self.opt, self.base_version)
+		return '{}{}'.format(self.opt if self.opt != DEFAULT_CRITERION_OPERATOR else '', self.base_version)
 
 
 class VersionRequirement:
+	"""
+	A version requirement tester
+
+	It can test if a given :class:`Version` object matches its requirement
+	"""
 	CRITERIONS = {
 		'<=': lambda base, ver: ver <= base,
 		'>=': lambda base, ver: ver >= base,
@@ -122,6 +173,10 @@ class VersionRequirement:
 	}
 
 	def __init__(self, requirements: str):
+		"""
+		:param requirements: The requirement string, which contains several version predicates connected by space character.
+			e.g. ``">=1.0.x"``, ``"^2.9"``, ``">=1.2.0 <1.4.3"``
+		"""
 		if not isinstance(requirements, str):
 			raise VersionParsingError('Requirements should be a str, not {}'.format(type(requirements).__name__))
 		self.criterions = []  # type: List[Criterion]
@@ -133,11 +188,11 @@ class VersionRequirement:
 						base_version = requirement[len(prefix):]
 						break
 				else:
-					opt = '='
+					opt = DEFAULT_CRITERION_OPERATOR
 					base_version = requirement
 				self.criterions.append(Criterion(opt, Version(base_version), self.CRITERIONS[opt]))
 
-	def accept(self, version: Version or str):
+	def accept(self, version: Union[Version, str]):
 		if isinstance(version, str):
 			version = Version(version)
 		for criterion in self.criterions:
@@ -151,5 +206,3 @@ class VersionRequirement:
 
 class VersionParsingError(ValueError):
 	pass
-
-
